Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(358)

Unified Diff: samples/newissues/newissues.dart

Issue 10823352: Rename XMLHttpRequest to HttpRequest. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: samples/newissues/newissues.dart
===================================================================
--- samples/newissues/newissues.dart (revision 10850)
+++ samples/newissues/newissues.dart (working copy)
@@ -41,16 +41,16 @@
}
/**
* Sends a XMLHTTPRequest and returns a future fo the date.
*/
Future<Dynamic> requestJson(String url) {
Completer c = new Completer<Dynamic>();
- void callback(XMLHttpRequest xhr) {
- if (xhr.readyState == XMLHttpRequest.DONE) {
+ void callback(HttpRequest xhr) {
+ if (xhr.readyState == HttpRequest.DONE) {
c.complete(JSON.parse(xhr.response));
}
};
- new XMLHttpRequest.get(url, callback);
+ new HttpRequest.get(url, callback);
return c.future;
}
@@ -41,16 +41,16 @@
}
/**
- * Sends a XMLHTTPRequest and returns a future fo the date.
+ * Sends a HTTPRequest and returns a future fo the date.
*/
Future<Dynamic> requestJson(String url) {

Powered by Google App Engine
This is Rietveld 408576698